@@ -10,12 +10,18 @@ from datetime import datetime
 
 import click
 from packaging import version
-from xdg import xdg_config_home, xdg_data_home
+
+if sys.version_info[0:2] <= (3, 9):
+    # xdg was deprecated and renamed xdg_base_dirs but only for python >= 3.10
+    import xdg as xdg_base_dirs
+else:
+    import xdg_base_dirs
 
 import osxphotos
 from osxphotos._constants import APP_NAME
 from osxphotos._version import __version__
-from osxphotos.utils import get_latest_version, get_macos_version
+from osxphotos.platform import get_macos_version
+from osxphotos.utils import get_latest_version
 
 # used to show/hide hidden commands
 OSXPHOTOS_HIDDEN = not bool(os.getenv("OSXPHOTOS_SHOW_HIDDEN", default=False))
@@ -83,7 +89,8 @@ def get_photos_db(*db_options):
 
 def get_config_dir() -> pathlib.Path:
     """Get the directory where config files are stored; create it if necessary."""
-    config_dir = xdg_config_home() / APP_NAME
+    # use xdg_base_dirs.xdg_config_home instead of importing xdg_config_home directly to make it easier to mock in tests
+    config_dir = xdg_base_dirs.xdg_config_home() / APP_NAME
     if not config_dir.is_dir():
         config_dir.mkdir(parents=True)
     return config_dir
@@ -91,7 +98,8 @@ def get_config_dir() -> pathlib.Path:
 
 def get_data_dir() -> pathlib.Path:
     """Get the director where local user data files are stored; create it if necessary"""
-    data_dir = xdg_data_home() / APP_NAME
+    # use xdg_base_dirs.xdg_data_home instead of importing xdg_data_home directly to make it easier to mock in tests
+    data_dir = xdg_base_dirs.xdg_data_home() / APP_NAME
     if not data_dir.is_dir():
         data_dir.mkdir(parents=True)
     return data_dir
