@@ -331,6 +331,7 @@ def export_db_migrate_photos_library(
     photosdb = PhotosDB(dbfile=photos_library, verbose=verbose)
     photosdb_fingerprint = {}
     photosdb_cloud_guid = {}
+    photosdb_name_size = {}
     photosdb_shared = {}
     for photo in photosdb.photos():
         photosdb_fingerprint[
@@ -339,6 +340,9 @@ def export_db_migrate_photos_library(
         photosdb_cloud_guid[
             f"{photo.original_filename}:{photo.cloud_guid}"
         ] = photo.uuid
+        photosdb_name_size[
+            f"{photo.original_filename}:{photo.original_filesize}"
+        ] = photo.uuid
         if photo.shared:
             photosdb_shared[_shared_photo_key(photo)] = photo.uuid
     verbose("Matching photos in export database to photos in Photos library")
@@ -381,6 +385,18 @@ def export_db_migrate_photos_library(
                 )
                 matched += 1
                 continue
+        if original_filesize := photoinfo.get("original_filesize", None):
+            key = f"{photoinfo['original_filename']}:{original_filesize}"
+            if key in photosdb_name_size:
+                new_uuid = photosdb_name_size[key]
+                verbose(
+                    f"[green]Matched by name and size[/green]: [uuid]{uuid}[/] -> [uuid]{new_uuid}[/]"
+                )
+                _export_db_update_uuid_info(
+                    conn, uuid, new_uuid, photoinfo, photosdb, dry_run
+                )
+                matched += 1
+                continue
         else:
             verbose(
                 f"[dark_orange]No match found for photo[/dark_orange]: [uuid]{uuid}[/], [filename]{photoinfo.get('original_filename')}[/]"
